@@ -86,19 +86,6 @@ static XEXT_GENERATE_FIND_DISPLAY(find_display, dmx_extension_info,
 
 static XEXT_GENERATE_CLOSE_DISPLAY(close_display, dmx_extension_info)
 
-#ifndef HAVE__XEATDATAWORDS
-#include <X11/Xmd.h>  /* for LONG64 on 64-bit platforms */
-
-static inline void _XEatDataWords(Display *dpy, unsigned long n)
-{
-# ifndef LONG64
-    if (n >= (ULONG_MAX >> 2))
-        _XIOError(dpy);
-# endif
-    _XEatData (dpy, n << 2);
-}
-#endif
-
 
 /*****************************************************************************
  *                                                                           *
@@ -453,8 +440,7 @@ Bool DMXAddScreen(Display *dpy, const char *displayName, unsigned int mask,
     req->length           += _DMXDumpScreenAttributes(dpy, mask, attr);
 
     if (length) {
-        char *buffer       = Xmalloc(paddedLength);
-        memset(buffer, 0, paddedLength);
+        char *buffer       = Xcalloc(paddedLength, 1);
         memcpy(buffer, displayName, length);
         Data32(dpy, buffer, paddedLength);
         Xfree(buffer);
@@ -793,8 +779,7 @@ Bool DMXAddInput(Display *dpy, unsigned int mask, DMXInputAttributes *attr,
     req->length           += _DMXDumpInputAttributes(dpy, mask, attr);
 
     if (length) {
-        char *buffer       = Xmalloc(paddedLength);
-        memset(buffer, 0, paddedLength);
+        char *buffer       = Xcalloc(paddedLength, 1);
         memcpy(buffer, attr->name, paddedLength);
         Data32(dpy, buffer, paddedLength);
         Xfree(buffer);
